@@ -216,6 +216,9 @@ computer_clock_update_func (ClockData * cd,
   		gtk_tooltips_set_tip (panel_tooltips, GTK_WIDGET (cd->applet),
 				      utf8, NULL);
 		g_free (utf8);
+	} else {
+  		gtk_tooltips_set_tip (panel_tooltips, GTK_WIDGET (cd->applet),
+				      NULL, NULL);
 	}
 	
 	/*if we are vertical, just make it char per line */
@@ -664,7 +667,7 @@ fill_clock_applet(PanelApplet *applet)
 	setup_gconf (cd);
 
 	error = NULL;
-	cd->hourformat = panel_applet_gconf_get_bool (applet, KEY_HOUR_FORMAT, &error);
+	cd->hourformat = panel_applet_gconf_get_int (applet, KEY_HOUR_FORMAT, &error);
 	if (error) {
 		/* Do NOT translate the clock/hourformat= part.  What you
 		 * should change is the number 12.  If your country code should use
@@ -679,13 +682,15 @@ fill_clock_applet(PanelApplet *applet)
 			cd->hourformat = 12;
 		} else {
 			cd->hourformat = atoi (transl + len);
-			if (cd->hourformat != 12 && cd->hourformat != 24)
-				cd->hourformat = 12;
 		}
 
 		g_error_free (error);
 	}
 
+	/* ensure value is valid */
+	if (cd->hourformat != 12 && cd->hourformat != 24)
+		cd->hourformat = 12;
+
 	error = NULL;
 	cd->showdate = panel_applet_gconf_get_bool (applet, KEY_SHOW_DATE, &error);
 	if (error) {
